========================================
Python 'requirements.txt' file generator
========================================

Usage
=====

.. code-block:: python

    from Reqtxt.reqtxt import Reqtxt

    project_dir = 'my-project/'
    reqtxt = Reqtxt(project_dir)
